pub struct RandomWalk<T: FloatExt = f64> { /* private fields */ }Expand description
Random walk with heavy-tailed jump lengths.
Mathematical Formulation
The path is represented by
$$X_n = X_0 + \sum_{i=1}^{n} A_i,$$
where the jump lengths (A_i) are sampled from an alpha-stable law and then
assigned a sign according to probability.
Implementations
Sourceimpl<T: FloatExt> RandomWalk<T>
impl<T: FloatExt> RandomWalk<T>
Sourcepub fn new(probability: T, alpha: T, start_position: T) -> XResult<Self>
pub fn new(probability: T, alpha: T, start_position: T) -> XResult<Self>
Create a new RandomWalk
Arguments
probability- The probability of the step in the positive directionalpha- The alpha parameter of the stable distributionstart_position- The starting position
Example
use diffusionx::simulation::discrete::RandomWalk;
let rw = RandomWalk::new(0.5, 1.0, 0.0).unwrap();Sourcepub fn probability(&self) -> T
pub fn probability(&self) -> T
Get the probability of the step in the positive direction
Sourcepub fn start_position(&self) -> T
pub fn start_position(&self) -> T
Get the starting position