BirthDeath

Struct BirthDeath 

pub struct BirthDeath<T: FloatExt = f64, X: RealExt = T> { /* private fields */ }
Birth-death process.

Mathematical Formulation

A birth-death process tracks a population whose state increases by one at birth events and decreases by one at death events.

Implementations

Source

impl<T: FloatExt, X: RealExt> BirthDeath<T, X>

pub fn new(lambda: T, mu: T) -> XResult<Self>

Create a new BirthDeath

Arguments
  • lambda - The rate of birth.
  • mu - The rate of death.
Example
use diffusionx::simulation::point::BirthDeath;

let birth_death = BirthDeath::new(1.0, 1.0).unwrap();
pub fn get_lambda(&self) -> T

Get the rate of birth

pub fn get_mu(&self) -> T

Get the rate of death