PlotConfigBuilder

Struct PlotConfigBuilder 

pub struct PlotConfigBuilder { /* private fields */ }
Available on crate feature visualize only.
Builder for PlotConfig.

Implementations

Source

impl PlotConfigBuilder

pub fn backend(&mut self, value: PlotterBackend) -> &mut Self

Backend

pub fn background_color(&mut self, value: Color) -> &mut Self

Background color

pub fn title<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Title

pub fn title_font_family<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

Font family of the title

pub fn title_font_size<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self

Font size of the title

pub fn title_font_style(&mut self, value: FontStyle) -> &mut Self

Font style of the title

pub fn caption<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Caption

pub fn caption_font_family<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

Font family of the caption

pub fn caption_font_size<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self

Font size of the caption

pub fn caption_font_style(&mut self, value: FontStyle) -> &mut Self

Font style of the caption

pub fn margin<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self

The desired size of the four chart margins in backend units (pixels).

pub fn x_label_area_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self

The desired size of the X label area in backend units (pixels). If set to 0, the X label area is removed.

pub fn y_label_area_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self

The desired size of the Y label area in backend units (pixels). If set to 0, the Y label area is removed.

pub fn x_spec<VALUE: Into<Range<f64>>>(&mut self, value: VALUE) -> &mut Self

Specifies the X axis range and data properties

pub fn y_spec<VALUE: Into<Range<f64>>>(&mut self, value: VALUE) -> &mut Self

Specifies the Y axis range and data properties

pub fn x_label<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

X-axis label

pub fn y_label<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Y-axis label

pub fn time_step<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self

Time step

pub fn size<VALUE: Into<(u32, u32)>>(&mut self, value: VALUE) -> &mut Self

Size (width, height) of the plot (pixels)

pub fn output_path<VALUE: Into<PathBuf>>(&mut self, value: VALUE) -> &mut Self

Output file path

pub fn show_grid(&mut self, value: bool) -> &mut Self

Whether to show grid lines

pub fn line_color(&mut self, value: Color) -> &mut Self

Line color

pub fn line_style(&mut self, value: LineStyle) -> &mut Self

Line style

pub fn show_legend(&mut self, value: bool) -> &mut Self

Whether to show legend

pub fn legend<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Legend title

pub fn show_points(&mut self, value: bool) -> &mut Self

Whether to show points

pub fn point_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self

Size of the points

pub fn filled(&mut self, value: bool) -> &mut Self

Whether to fill the points with color

pub fn dash_style<VALUE: Into<[u32; 3]>>(&mut self, value: VALUE) -> &mut Self

Dash style pattern [dash_length, spacing, stroke_width]

pub fn dot_style<VALUE: Into<[u32; 2]>>(&mut self, value: VALUE) -> &mut Self

Dot style pattern size/stroke_width: The size/stroke_width of the marker spacing: The spacing between markers

pub fn stairs(&mut self, value: bool) -> &mut Self

Whether to show stairs

pub fn legend_position(&mut self, value: LegendPosition) -> &mut Self

Legend position

pub fn build(&self) -> Result<PlotConfig, PlotConfigBuilderError>

Builds a new PlotConfig.

Errors

If a required field has not been initialized.