pub struct BirthDeath<T: FloatExt = f64, X: RealExt = T> { /* private fields */ }Expand description
Birth-death process.
Mathematical Formulation
A birth-death process tracks a population whose state increases by one at birth events and decreases by one at death events.
Implementations
Sourceimpl<T: FloatExt, X: RealExt> BirthDeath<T, X>
impl<T: FloatExt, X: RealExt> BirthDeath<T, X>
Sourcepub fn get_lambda(&self) -> T
pub fn get_lambda(&self) -> T
Get the rate of birth