pub struct PlotConfigBuilder { /* private fields */ }visualize only.Expand description
Builder for PlotConfig.
Implementations
Sourceimpl PlotConfigBuilder
impl PlotConfigBuilder
Sourcepub fn backend(&mut self, value: PlotterBackend) -> &mut Self
pub fn backend(&mut self, value: PlotterBackend) -> &mut Self
Backend
Sourcepub fn background_color(&mut self, value: Color) -> &mut Self
pub fn background_color(&mut self, value: Color) -> &mut Self
Background color
Sourcepub fn title_font_family<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn title_font_family<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Font family of the title
Sourcepub fn title_font_size<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
pub fn title_font_size<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
Font size of the title
Sourcepub fn title_font_style(&mut self, value: FontStyle) -> &mut Self
pub fn title_font_style(&mut self, value: FontStyle) -> &mut Self
Font style of the title
Sourcepub fn caption_font_family<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn caption_font_family<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Font family of the caption
Sourcepub fn caption_font_size<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
pub fn caption_font_size<VALUE: Into<f64>>(&mut self, value: VALUE) -> &mut Self
Font size of the caption
Sourcepub fn caption_font_style(&mut self, value: FontStyle) -> &mut Self
pub fn caption_font_style(&mut self, value: FontStyle) -> &mut Self
Font style of the caption
Sourcepub fn margin<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn margin<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
The desired size of the four chart margins in backend units (pixels).
Sourcepub fn x_label_area_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn x_label_area_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
The desired size of the X label area in backend units (pixels). If set to 0, the X label area is removed.
Sourcepub fn y_label_area_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn y_label_area_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
The desired size of the Y label area in backend units (pixels). If set to 0, the Y label area is removed.
Sourcepub fn x_spec<VALUE: Into<Range<f64>>>(&mut self, value: VALUE) -> &mut Self
pub fn x_spec<VALUE: Into<Range<f64>>>(&mut self, value: VALUE) -> &mut Self
Specifies the X axis range and data properties
Sourcepub fn y_spec<VALUE: Into<Range<f64>>>(&mut self, value: VALUE) -> &mut Self
pub fn y_spec<VALUE: Into<Range<f64>>>(&mut self, value: VALUE) -> &mut Self
Specifies the Y axis range and data properties
Sourcepub fn size<VALUE: Into<(u32, u32)>>(&mut self, value: VALUE) -> &mut Self
pub fn size<VALUE: Into<(u32, u32)>>(&mut self, value: VALUE) -> &mut Self
Size (width, height) of the plot (pixels)
Sourcepub fn output_path<VALUE: Into<PathBuf>>(&mut self, value: VALUE) -> &mut Self
pub fn output_path<VALUE: Into<PathBuf>>(&mut self, value: VALUE) -> &mut Self
Output file path
Sourcepub fn line_color(&mut self, value: Color) -> &mut Self
pub fn line_color(&mut self, value: Color) -> &mut Self
Line color
Sourcepub fn line_style(&mut self, value: LineStyle) -> &mut Self
pub fn line_style(&mut self, value: LineStyle) -> &mut Self
Line style
Sourcepub fn show_legend(&mut self, value: bool) -> &mut Self
pub fn show_legend(&mut self, value: bool) -> &mut Self
Whether to show legend
Sourcepub fn show_points(&mut self, value: bool) -> &mut Self
pub fn show_points(&mut self, value: bool) -> &mut Self
Whether to show points
Sourcepub fn point_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn point_size<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
Size of the points
Sourcepub fn dash_style<VALUE: Into<[u32; 3]>>(&mut self, value: VALUE) -> &mut Self
pub fn dash_style<VALUE: Into<[u32; 3]>>(&mut self, value: VALUE) -> &mut Self
Dash style pattern [dash_length, spacing, stroke_width]
Sourcepub fn dot_style<VALUE: Into<[u32; 2]>>(&mut self, value: VALUE) -> &mut Self
pub fn dot_style<VALUE: Into<[u32; 2]>>(&mut self, value: VALUE) -> &mut Self
Dot style pattern size/stroke_width: The size/stroke_width of the marker spacing: The spacing between markers
Sourcepub fn legend_position(&mut self, value: LegendPosition) -> &mut Self
pub fn legend_position(&mut self, value: LegendPosition) -> &mut Self
Legend position
Sourcepub fn build(&self) -> Result<PlotConfig, PlotConfigBuilderError>
pub fn build(&self) -> Result<PlotConfig, PlotConfigBuilderError>